summaryrefslogtreecommitdiff
path: root/cpukit/include/rtems/score/threadimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/include/rtems/score/threadimpl.h')
-rw-r--r--cpukit/include/rtems/score/threadimpl.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/cpukit/include/rtems/score/threadimpl.h b/cpukit/include/rtems/score/threadimpl.h
index 54f6c8c797..b4b85ffa90 100644
--- a/cpukit/include/rtems/score/threadimpl.h
+++ b/cpukit/include/rtems/score/threadimpl.h
@@ -134,16 +134,21 @@ typedef struct {
const struct _Scheduler_Control *scheduler;
/**
* @brief The starting address of the thread area.
*/
void *stack_area;
/**
* @brief The size of the thread area in bytes.
*/
size_t stack_size;
/**
+ * @brief The address of the allocated stack area or NULL.
+ */
+ void *allocated_stack;
+
+ /**
* @brief The new thread's priority.
*/
Priority_Control priority;
@@ -134,16 +134,21 @@ typedef struct {
const struct _Scheduler_Control *scheduler;
/**
- * @brief The starting address of the thread area.
+ * @brief The starting address of the stack area.
*/
void *stack_area;
@@ -134,16 +134,21 @@ typedef struct {
void *stack_area;
/**
- * @brief The size of the thread area in bytes.
+ * @brief The size of the stack area in bytes.
*/
size_t stack_size;